var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp, _initialiseProps;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import * as React from 'react';
import Radium from 'radium';
import PropTypes from 'prop-types';
import style from './style';
import Button from '../Button';

var Table = (_temp = _class = function (_React$Component) {
  _inherits(Table, _React$Component);

  function Table(props) {
    _classCallCheck(this, Table);

    var _this = _possibleConstructorReturn(this, _React$Component.call(this, props));

    _initialiseProps.call(_this);

    var items = props.items;


    _this.state = {
      items: items
    };
    return _this;
  }

  Table.prototype.componentWillReceiveProps = function componentWillReceiveProps(nextProps) {
    if (nextProps.items !== this.props.items) {
      this.setState(function (prev) {
        return _extends({}, prev, {
          items: nextProps.items
        });
      });
    }
  };

  Table.prototype.render = function render() {
    var _props = this.props,
        children = _props.children,
        header = _props.header,
        onAddItem = _props.onAddItem;

    var headerColumns = [];
    var rowColumns = [];
    var footerColumns = [];

    React.Children.forEach(children, function (child) {
      if (!child.type || child.type.displayName !== 'TableColumn') throw new Error('Child component should be instance of <TableColumn />');

      var _child$props = child.props,
          header = _child$props.header,
          propName = _child$props.propName,
          footer = _child$props.footer,
          width = _child$props.width,
          action = _child$props.action;

      // Fill headers columns

      headerColumns.push({ header: header, width: width, action: action });

      // Fill row columns
      rowColumns.push({ propName: propName, width: width, action: action });

      // Fill footer
      footerColumns.push({ footer: footer, width: width, action: action });
    });

    return React.createElement(
      'div',
      { style: style.root },
      React.createElement(
        'div',
        {
          className: 'root-top',
          style: style.rootTop
        },
        React.createElement(
          'h1',
          null,
          header
        ),
        React.createElement(
          'div',
          {
            className: 'actions-pane-top',
            style: style.tableTopActions
          },
          onAddItem && React.createElement(
            Button,
            { className: 'add-new-item-btn', onClick: onAddItem, type: 'small' },
            'Add Item'
          )
        )
      ),
      React.createElement(
        'div',
        {
          className: 'root-body',
          style: style.rootBody
        },
        React.createElement(
          'div',
          {
            className: 'table-header',
            style: style.header
          },
          this._renderHeaders(headerColumns)
        ),
        React.createElement(
          'div',
          {
            className: 'table-body',
            style: style.body
          },
          rowColumns.length > 0 && this._renderRows(rowColumns)
        ),
        React.createElement('div', {
          className: 'table-footer',
          style: style.footer
        })
      ),
      React.createElement('div', {
        className: 'root-footer',
        style: style.rootFooter
      })
    );
  };

  return Table;
}(React.Component), _class.defaultProps = {
  items: [],
  canAddNewItem: false,
  header: ''
}, _initialiseProps = function _initialiseProps() {
  var _this2 = this;

  this._renderHeaders = function (headerColumns) {
    return headerColumns.map(function (_ref, index) {
      var header = _ref.header,
          width = _ref.width,
          action = _ref.action;
      return React.createElement(
        'div',
        { className: 'table-header-column', key: index, style: [style.tableHeaderColumn, { flex: width }] },
        !action ? header : ''
      );
    });
  };

  this._renderRows = function (rowColumns) {
    var items = _this2.state.items;

    return items.map(function (rowData, rowIndex) {
      return React.createElement(
        'div',
        { className: 'table-row', key: rowIndex, style: [style.tableRow, rowIndex % 2 === 0 && style.even] },
        _this2._renderRowColumns(rowColumns, rowData)
      );
    });
  };

  this._renderRowColumns = function (rowColumns, rowData) {
    return rowColumns.map(function (column, index) {
      var columnData = rowData[column.propName];
      if (column.action) {
        return React.createElement(
          'div',
          { className: 'table-row-action', key: index, style: style.tableRowActionColumn },
          columnData
        );
      } else {
        return React.createElement(
          'div',
          { className: 'table-row-column', key: index, style: style.tableRowColumn },
          columnData
        );
      }
    });
  };
}, _temp);
Table.propTypes = process.env.NODE_ENV !== "production" ? {
  items: PropTypes.array.isRequired,
  canAddNewItem: PropTypes.bool,
  children: PropTypes.node,
  onAddItem: PropTypes.func
} : {};
;

export default Radium(Table);